<?xml version="1.0" encoding="UTF-8"?>
<!--
***********************************************************
** viewMsg.xslt
**
** Shows details for a specific message.
***********************************************************
-->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="utils.xslt"/>
	<xsl:param name="rootDir" select="'../docroot/'"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" 
		indent="yes" 
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>
		
   <!--
	**********************************************************
	** Create the XHTML web page
	*******************************************************-->
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>View Message</title>
				<link href="{$rootDir}forum.css" 
						rel="stylesheet" type="text/css"/>
			</head>
			<body>
				<div class="box1">
					<h1>View Message</h1>
					<div>
						<xsl:value-of select="message/board/name"/>
					</div>
				</div>
				<!-- ===== Quick Actions ====== -->
				<h3>Quick Actions</h3>
				<ul>
					<li>Return to 
					<a href="viewMonth?boardID={message/board/@id}&amp;month={message/@month}&amp;year={message/@year}">
							<xsl:call-template name="utils.printLongMonthName">
								<xsl:with-param name="monthNumber" select="message/@month"/>
							</xsl:call-template>,
					<xsl:value-of select="message/@year"/>
						</a> messages for <xsl:value-of select="message/board/name"/>
					</li>
					<li>Return to the <a href="home">home page</a>
					</li>
					<li>
						<a href="postMsg?mode=replyToMsg&amp;origMsgID={message/@id}">Reply</a> 
							to this message</li>
				</ul>
				<h3>Message</h3>
				<div class="box2">
					<xsl:apply-templates select="message"/>
				</div>
			</body>
		</html>
	</xsl:template>
	
	<!--
	**********************************************************
	** Show details for the <message> element
	*******************************************************-->
	<xsl:template match="message">
		<div>
			<div style="font-weight: bold;">
				<xsl:value-of select="subject"/>
			</div>
			<xsl:text> posted by </xsl:text>
			<a href="mailto:{authorEmail}">
				<xsl:value-of select="authorEmail"/>
			</a>
			<xsl:text> on </xsl:text>
			<xsl:call-template name="utils.printShortMonthName">
				<xsl:with-param name="monthNumber" select="@month"/>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:value-of select="@day"/>
			<xsl:text>, </xsl:text>
			<xsl:value-of select="@year"/>
			<xsl:apply-templates select="inResponseTo"/>
		</div>
		<pre>
			<xsl:value-of select="text"/>
		</pre>
	</xsl:template>
	
	<!--
	**********************************************************
	** Show a link to the message that this one is in
	** response to.
	*******************************************************-->
	<xsl:template match="inResponseTo">
		<div style="text-indent: 2em;">
			<xsl:text>In response to </xsl:text>
			<a href="viewMsg?msgID={@id}">
				<xsl:value-of select="subject"/>
			</a>
		</div>
	</xsl:template>
</xsl:stylesheet>
